#ifndef View_H
#define View_H

#include <iostream>

#include <QApplication>
#include <QMainWindow>
#include <QTextCodec>
#include <QMenuBar>
#include <QListView>
#include <QTableView>
#include <QLabel>
#include <QSpinBox>
#include <QCheckBox>
#include <QPushButton>
#include <QTimer>
#include <QGroupBox>
#include <QMessageBox>
#include <QGridLayout>
#include <QVBoxLayout>
#include <QHeaderView>
#include <QResizeEvent>

#include <Controller.hpp>
#include <ParameterDelegate.hpp>
#include <simple_logger.hpp>

namespace hatptester{

class MainWindow : public QMainWindow{
	Q_OBJECT

private :
	MainWindow(const MainWindow&);
	MainWindow& operator=(const MainWindow&);

	HATPController& controller;

	QWidget centralPart;
	
	QGroupBox taskBox;
	QListView taskView;
	
	QGroupBox parameterBox;
	const std::string defaultText;
	QTableView parametersView;
	
	QLabel informationsText;

	QAction quitAction;
	QAction sendAction;

	QAction aboutAction;
	
	QCheckBox maxTimeToggle;
	QSpinBox maxTimeValue;
	bool changeToggle;
	QPushButton maxTimeButton;
	
	QPushButton sendFirstPlanRequestButton;
	QPushButton sendAllPlansRequestButton;
	
	QTimer timer; //This timer will be used to check every half a second that the client is still connected
		
public :
	MainWindow();
	
	void resizeEvent(QResizeEvent* event);
		
public slots:
	void about();
	
	void sendFirstPlanRequest();
	
	void sendAllPlansRequest();
	
	void activateSend();
	
	void updateInformations();
	
	void clicTask(const QModelIndex& index);
	
	void periodicCheck();
	
	void maxTimeToggled(int);
	
	void maxTimeChanged(int);
	
	void sendMaxTime();
};

}; //namespace

#endif //View_H
